SeoButton class

A SEO-friendly button widget that can render both a Flutter ElevatedButton and an equivalent HTML <button> element when running on the web.

This widget implements SeoInjectable so that it can create a DOM representation for search engines and web crawlers.

Features:

  • Works as a normal Flutter ElevatedButton in native apps.
  • Creates an HTML <button> for SEO purposes in Flutter Web.
  • Allows custom styling, text, and accessibility attributes.
Inheritance
Implemented types

Constructors

SeoButton({Key? key, required String label, TextStyle? labelStyle, VoidCallback? onPressed, String? id, ButtonStyle? style})
Creates a SeoButton widget.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String?
Optional HTML element id for the button in the DOM.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → String
The text label displayed on the button.
final
labelStyle → TextStyle?
Optional text style for the button label in Flutter UI.
final
onPressed → VoidCallback?
Callback when the button is pressed in Flutter UI.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → ButtonStyle?
Optional Flutter button style.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
createHtmlElement() → WebHTMLElement?
Creates and returns a WebHTMLElement to represent this object in the DOM.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited