flutter_dom_ui
library
Classes
SeoAppBar
A Flutter AppBar widget that supports SEO-friendly HTML injection.
SeoBottomNavigationBar
A BottomNavigationBar widget that also supports injecting
semantic HTML for SEO purposes when running on the web.
SeoButton
A SEO-friendly button widget that can render both a Flutter ElevatedButton
and an equivalent HTML <button> element when running on the web.
SeoCard
A card widget that not only displays content in Flutter,
but also injects an equivalent HTML <div> structure for SEO purposes
when running on web.
SeoCenter
A SEO-friendly equivalent of Flutter's Center widget.
SeoChoicechip
A Flutter ChoiceChip widget that also injects a semantic HTML <button>
element into the DOM when running on Web, enabling better SEO and accessibility.
SeoColumn
A SEO-friendly equivalent of Flutter's Column widget.
SeoConstrainedBox
A constrainedbox widget that not only displays content in Flutter,
but also injects an equivalent HTML <div> structure for SEO purposes
when running on web.
SeoContainer
A container widget that not only displays content in Flutter,
but also injects an equivalent HTML <div> structure for SEO purposes
when running on web.
A semantic <footer> container for Flutter web apps with SEO-friendly HTML injection.
SeoGridView
A scrollable grid widget that renders a Flutter GridView and
injects a corresponding HTML structure for SEO purposes on the web.
SeoImage
A widget that displays an image and injects a corresponding HTML <img>
element into the DOM for SEO purposes when running on the web.
SeoInitializer
A widget that ensures a hidden SEO-friendly HTML container exists in the DOM.
SeoLink
A widget that renders a clickable link in Flutter and injects
a corresponding HTML <a> element for SEO purposes when running on the web.
SeoListView
A scrollable list widget that renders a Flutter ListView and
injects a corresponding HTML structure for SEO purposes on the web.
SeoPadding
A Padding -like widget that also injects a semantic HTML <div>
with corresponding CSS padding when running on Web.
SeoRow
A horizontal layout widget that behaves like a Flutter Row but
can inject a corresponding HTML <div> structure for SEO purposes
when running on the web.
SeoScaffold
A Scaffold-like widget designed for Flutter Web that automatically
injects SEO-friendly HTML meta tags and semantic HTML structure into the DOM.
SeoSingleChildScrollView
A scrollable container that behaves like SingleChildScrollView but
can inject a corresponding HTML <div> structure for SEO purposes
when running on the web.
SeoSizedBox
A SizedBox widget that not only displays content in Flutter,
but also injects an equivalent HTML <div> structure for SEO purposes
when running on web.
SeoText
A Flutter Text widget that can inject a corresponding HTML element
for SEO when running on the web.
SeoTextField
A Flutter TextField widget that can inject a corresponding HTML input
element for SEO when running on the web.
SeoWrap
A Wrap -like widget that arranges its children in a flow layout,
and injects an equivalent semantic HTML <div> using CSS flex-wrap
for SEO and accessibility purposes when running on Web.
Enums
InputType
Enum representing the type of input for the SEO text field.
TextTag
Enum representing common HTML text tags for SEO purposes.
Properties
webWindow
→ Window
Reference to the global window object in the browser.
final
Functions
clearElementChildren (HTMLElement container )
→ void
Removes all child nodes from the given container element.
Typedefs
WebDocument
= Document
Represents the HTML document object.
WebElement
= Element
Represents any generic DOM element.
WebHTMLDivElement
= HTMLDivElement
Represents an HTML <div> element in the DOM.
WebHTMLElement
= HTMLElement
Represents a generic HTML element in the DOM.
WebHTMLImageElement
= HTMLImageElement
Represents an HTML <img> element in the DOM.