SeoAppBar class
A Flutter AppBar widget that supports SEO-friendly HTML injection.
Implements SeoInjectableLayout for injecting HTML representation of the AppBar into the DOM, and PreferredSizeWidget to specify height.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SeoAppBar
- Implemented types
Constructors
-
SeoAppBar({Key? key, Widget? leading, Widget? title, List<
Widget> ? actions, Widget? flexibleSpace, Color? shadowColor, Color? surfaceTintColor, ShapeBorder? shape, Color? backgroundColor, Color? foregroundColor, IconThemeData? iconTheme, IconThemeData? actionsIconTheme, bool? automaticallyImplyLeading = true, double? toolbarHeight = kToolbarHeight, double? leadingWidth, bool? centerTitle, TextStyle? toolbarTextStyle, TextStyle? titleTextStyle}) -
Creates a SeoAppBar with optional parameters.
const
Properties
-
actions
→ List<
Widget> ? -
Widgets to display on the right side of the AppBar.
final
- actionsIconTheme → IconThemeData?
-
Theme for action icons in the AppBar.
final
- automaticallyImplyLeading → bool?
-
Whether the leading widget should be automatically implied if null.
final
- backgroundColor → Color?
-
Background color of the AppBar.
final
- centerTitle → bool?
-
Whether the title should be centered.
final
- flexibleSpace → Widget?
-
A widget behind the toolbar and the tab bar.
final
- foregroundColor → Color?
-
Foreground color of AppBar content.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconTheme → IconThemeData?
-
Theme for icons in the AppBar.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- leading → Widget?
-
The widget displayed before the title, typically an icon or back button.
final
- leadingWidth → double?
-
Width reserved for the leading widget.
final
- preferredSize → Size
-
The preferred size of the AppBar, based on toolbarHeight.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadowColor → Color?
-
The color of the AppBar's shadow.
final
- shape → ShapeBorder?
-
The shape of the AppBar's material.
final
- surfaceTintColor → Color?
-
Surface tint color overlay for the AppBar.
final
- title → Widget?
-
The primary widget displayed in the AppBar, usually a Text widget.
final
- titleTextStyle → TextStyle?
-
Text style for the title widget.
final
- toolbarHeight → double?
-
Height of the toolbar.
final
- toolbarTextStyle → TextStyle?
-
Text style for the toolbar widgets.
final
Methods
-
build(
BuildContext context) → Widget -
Builds the Flutter AppBar widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
injectHtmlTo(
WebHTMLElement parent) → void -
Injects the AppBar as SEO-friendly HTML elements into the
parentcontainer.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited