SeoLink class
A widget that renders a clickable link in Flutter and injects
a corresponding HTML <a> element for SEO purposes when running on the web.
This is useful because Flutter Web renders primarily in a <canvas>,
which is not indexable by search engines. By implementing SeoInjectable,
this widget ensures that crawlers can read and index the link as real HTML.
Example usage:
SeoLink(
href: 'https://example.com',
text: 'Visit Example',
title: 'Go to example.com',
onTap: () => print('Link clicked!'),
)
When running on the web, this will also create an HTML <a> element
with the given href, text, and title attributes.
- Inheritance
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- href → String
-
The URL the link points to.
final
- id → String?
-
Optional HTML
idattribute for the<a>element. If not provided, a random ID is generated.final - key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onTap → void Function()?
-
Optional callback triggered when the link is tapped in Flutter.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → TextStyle?
-
Optional text style for the Flutter widget.
final
- text → String
-
The text to display for the link.
final
- title → String?
-
Optional title attribute for the HTML
<a>element.final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
createHtmlElement(
) → WebHTMLElement? -
Creates and returns a WebHTMLElement to represent this object in the DOM.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited